@@ -2,15 +2,11 @@ from typing import Optional, List, Dict
 from secoda_common.models.user import User
 from secoda_common.models.table import TableSummary
 from secoda_common.models.dashboard import DashboardSummary
+from secoda_common.models.tag import Tag
 
 import attr
 from marshmallow_annotations.ext.attrs import AttrsSchema
 
-@attr.s(auto_attribs=True, kw_only=True)
-class Tag:
-    tag_type: str
-    tag_name: str
-
 @attr.s(auto_attribs=True, kw_only=True)
 class DictionaryTerm:
   key: str
