@@ -95,6 +95,24 @@ class ColumnNTile:
     left_bound: str
     right_bound: str
     percent_filled: float
+    label: Optional[str]
+
+
+@attr.s(auto_attribs=True, kw_only=True)
+class ColumnDistribution:
+    key: Optional[str]
+    min: Optional[float]
+    max: Optional[float]
+    median: Optional[float]
+    mean: Optional[float]
+    count: Optional[int]
+    unique: Optional[int]
+
+
+class ColumnDistributionSchema(AttrsSchema):
+    class Meta:
+        target = ColumnDistribution
+        register_as_scheme = True
 
 
 class ColumnNTileSchema(AttrsSchema):
@@ -132,6 +150,7 @@ class Column:
     badges: Optional[List[Badge]] = []
     tags: Optional[List[Tag]] = []
     is_pk: Optional[bool] = None
+    distribution: Optional[ColumnDistribution] = attr.ib(default=None)
     column_references: Optional[List[ColumnReference]] = None
     properties: Optional[List[ColumnProperty]] = None
     ntiles: Optional[List[ColumnNTile]] = None
